bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 20. Aventiure
___________________________________________________
| ### <Daz> was in einen citen do vrov Helche erstarp ### vnt daz der kvnich Ecel vmb ein ander vrowen warp ### so ritten sine vrivnde in der Bvrgondn lant ### ceiner stolcen wittewen div was vrov Criemhilt genant ### Sit daz erstorben wære der schonen Helchen lip ### si sprachen welt ir immer gewinnen edel wip ### di hohesten vnt di besten di chvnich ie gewan ### so nemt di selben vrowen der starche Sifrit was ir man
###### 1142 | ### Do sprach der chvnich riche wi moht daz ergan ### sit ich pin ein heiden vnt der tovffe nine han ### so ist div vrowe christen da von so lobt sis niht ### ez mvese sin ein wnder ob ez immer geschit
| ### Do sprachen aber di snellen waz ob siz lihte tvt ### dvrch iwern namen den hohen vnd iwer michel gvt ### so sol man daz versvchen an daz vil edel wip ### ir mveget vil gerne minnen den ir vil wætlichen lip
###### 1144 | ### Do sprach der kvnich edele wen ist nv bechant ### vnder iv bi Rine di livte vnd ovch daz ### do sprach von Bechelaren der gvte Rvedeger ### ich han erkant von kinde di edelen chvenege her [345b]
###### 1145 | ### Gvnther vnd Gernot di edeln ritter gvt ### der dritte heizet Giselher ir ietslicher tvt ### swaz er der besten eren vnd tvgende mach began ### ovch hant ir alten mage noch her daz selbe getan
| ### Do sprach aber Ecel vrivnt dv solt mir sagen ### op si in minem lande chrone solde tragen ### vnd ist ir lip so schoene als mir ist geseit ### den minen besten vrivnden sold ez nimmer werden leit
###### 1147 | ### Si gelichet sich wol mit schoene der lieben vrowen min ### Helchen der vil richen iane chonde niht gesin ### in dirre werlde schoener deheines chvniges wip ### den si lobt ce vrivnde der mach wol trosten sinen lip
###### 1148 | ### Er sprach so wirbez Rvedeger als liep als ich dir si ### vn sol ich Criemhilde immer geligen bi ### des wil ich dir lonen so ich aller beste chan ### so hastv minen willen so rehte verre getan
| ### Vzzer miner chameren so heiz ich dir geben ### daz dv vnt dine gesellen mveget vroliche leben ### von rossen vnd von chleidern allez daz dv wil ### des hiez ich iv bereiten zv der botscheffte vil
###### 1150 | ### Des antwrte Rvdeger der margrave rich ### gerte ich dines gvtes daz wære vnlobelich ### ich wil din bote gerne wesen an den Rin ### mit min selbes gvte daz ich han von der hende din
###### 1151 | ### Do sprach der chvenich riche nv wenne welt ir varn ### nach der minnechlichen got sol ivch bewarn ### der reise an allen eren vnt ovch di vrowen min ### des helfe mir gelveche daz si vns genedich mvezze sin
| ### Do sprach aber Rvedger e wir rvmen daz lant ### wir mvezzen ê bereiten wæffen vnt gewant ### also daz wirs ere vor fvrsten mvgen han ### ich wil ce Rine fveren fvmfhvndert wætlicher man
###### 1153 | ### Swa man cen Bvrgonden mich vnt di mine sehe ### daz ir ietslicher danne dir dis iehe ### daz nie chvenech deheiner also manigen [346a] man ### so verre baz gesande danne dv ce Rine hast getan
###### 1154 | ### Vnd ob dvz kvenich riche niht wil dar vmb lan ### si was in edelen minnen Sifride vndertan ### dem Sigemvndes chinde den hastv hie gesehen ### man moht im rehter eren mit maniger warheit iehen
| ### Do sprach der kvnich edele was si des recken wip ### so was wol also tivre des edelen fvrsten lip ### daz ich niht versmahen di chvneginne sol ### dvrch ir grozzen schone so gevallet si mir wol
###### 1156 | ### Do sprach der margrave so wil iv daz sagen ### daz wir vns heben hinnen in vier vnt zeweinzech tagen ### ich enbivte iz Gotelinde der lieben vrowen min ### daz ich nach Criemhilde selbe bote welle sin
###### 1157 | ### Hince bechelaren sande Rvedeger ### do wart div margrave trvrech vnd her ### ern bot ir daz er solde dem chvnige werben wip ### si gedahte minnechliche an der schonen Helchen lip
| ### Do div margravinne di botschaft vernam ### ein teil was ir leide weinens si gezam ### ob si gewinnen solde vrowen alsam ê ### so si gedaht an Helchen daz tet ir innechliche we
###### 1159 | ### Rvedeger von Vngern in siben tagen reit ### des was dr kvnech Ecel vro vnt gemeit ### da cer stat ce Wiene bereite man im wat ### done moht er siner reise do niht langer haben rat
###### 1160 | ### Da ce Bechelaren im warte Gotelint ### div ivnge margravinne daz Rvdegeres chint ### sah ir vater gerne vnt di sine man ### da wart ein liebez piten von schoenen chinden getan
| ### <De> daz der edel Rvedeger ce Bechelaren reit ### vz der stat ze Wiene do waren in ir chleit ### rehte vollechlichen vf den sovmen chomen ### di fvren in der maze daz in wart wenich iht genomen
###### 1162 | ### Do si ce Bechelaren chomen in di stat ### di sinen reisgesellen herbergen do bat ### der [346b] wirt vil minnechliche vnt schvf in gvt gemach ### Gotelint div riche den wirt vil gerne chomen sach
###### 1163 | ### Alsam tet sin liebiv tohter dev ivnge margravin ### derne chvnde nimmer sin chomen lieber sin ### di helde vz Hivnen landen wi gerne si si sach ### mit lachendem mvte div edele ivnchvrowe sprach
###### 1164 | ### <nv> si vns grozze willechomen min vater vnd sine man ### do wart ein schoene danchen mit vlize da getan ### der ivngen margravinne von manigem ritter gvt ### vil wol wesse Gotelint des herren Rvedegeres mvt
###### 1165 | ### Do si des nahtes nahen bi Rvdegeren lach ### wi gvetlich vragen div margravinne pflach ### war in gesendet hete der chvenich von Hvenen lant ### er sprach min vrowe Gotelint ich tvn dirz gern bechant
###### 1166 | ### Da sol ich minem herren werben ein ander wip ### sit daz ist verdorben der schonen Helchen lip ### ich wil nach Criemhilde riten an den Rin ### div sol hi cen Hivnen gewaltech sin
| ### Daz wolde got sprach Gotelint vnd mohte daz geschehen ### sit daz wir ir horen so maniger eren iehen ### si ergazt vns miner vrowen lihte in alten tagen ### ovch mohte wir si gerne cen Hivnen crone lazen tragen
###### 1168 | ### Do sprach der margrave trivtinne min ### di mit mir svlen riten hinnen an den Rin ### den svlt ir minnechliche bieten iwer gvt ### so helde varent riche so sint hohe gemvt
###### 1169 | ### Si sprach ez ist deheiner der iz gerne vor mir nimt ### ine gebe ir ietslichem swaz im wol gecimt ### ê daz ir hinnen scheidet vnd ovch iwer man ### do sprach der margrave daz ist mir liebe getan
| ### <Hey> waz man richer pfellel von ir kamer trvch ### der wart den edelen recken ce teile do genvch ### erfvllet vlizech [347a] lichen von hals vnz vf den sporn ### di im darzv gevielen di het im Rvdger vz erchorn
###### 1171 | ### An dem sibendem morgen von Bechelaren reit ### der wirt mit sinen recken waffen vnd chleit ### fvrten si den vollen dvrh der Beier lant ### si wrden vf der strazen dvrch rovben selten an gerant
###### 1172 | ### Inner tagen zwelfen si chomen an den Rin ### done chvnden disiv mære niht verholn sin ### man saget ez dem chvnige vnt ovch sinen man ### ez choemen vremde geste der wirt do vragen began
| ### Ob iemen si bechande man sold ez im sagen ### man sah ir sovmære so rehte swære tragen ### daz si vil riche waren daz wart da bechant ### man schvf in herberge in der witen stat cehant
###### 1174 | ### Do di vil vnchvnden waren in bechomen ### do wart der selben herren vaste war genomen ### si wnderte wannen fveren di recken an den Rin ### der wirt nach Hagen sande ob si im chvndech moehten sin
###### 1175 | ### Do sprach der helt von Tronege in han ir niht gesehen ### als wir si nv geschowen ich chan iv wol veriehen ### von <swann> si riten her in dizze lant ### si svlen sin vil vremde ine hab si schiere bechant
| ### Den gesten herberge waren nv genomen ### in vil richiv chleider was der bote bechomen ### vnd sine hergesellen ce hove si do ritten ### si fvrten gvtiv chleider vil harte spæhe gesnitten
###### 1177 | ### Do sprach der snelle Hagene als ich mih chan verstan ### wande ich den herren lange niht gesehen han ### si varent wol dem geliche sam ez si Rvdeger ### von hivnisschen landen der recke chvne vnd her
###### 1178 | ### Wi sol ich daz gelovben sprach der kvenich zehant ### daz der von Bechelaren si chomen in dizz lant ### als der chvnich Gvnther di rede vol gesprach ### Hagene der chvene den gvten Rvdegeren sach [347b]
| ### Er vnt sine vrivnde lieffen alle dan ### do sach man von den rossen fvnfhvndert ritter stan ### do wrden wol enpfangen di von Hivnen lant ### boten nie getrvgen also herlich gewant
###### 1180 | ### Do sprach harte lvte von Tronege Hagene ### nv sin gote willechomen dise degene ### der voget von Bechelaren vnt alle sine man ### der antpfanch wart wol mit eren den snellen Hivnen getan
###### 1181 | ### Des chveniges nehesten mage di giengen da man sach ### Ortwin von Mezze ce Rvedgeren sprach ### wir haben in aller wile mere nie gesehen ### geste hi so gern des wil ich wærliche gehen
| ### Des grvzes si do danchten den recken vber al ### mit den hergesinden si giengen in den sal ### da si den chvenich fvnden bi manigem herlichem man ### <der> herre stvnt von sedele daz was dvrch groze zvht getan
###### 1183 | ### Wi rehte zvehtechlichen er zv den boten gie ### Gvnther vnd Giselher vil vlizechlich enpfie ### den gast mit sinen mannen als im wol gezam ### den gvten Rvedger er bi der hende genam
###### 1184 | ### Er brahten zv dem sedele da er selbe saz ### den gesten hiez man shenchen vil gerne tet man daz ### met den vil gvten vnt den besten win ### dem man chvnde finden in dem lande al vmb den Rin
| ### Giselher vnd Gere di waren beide chomen ### Dancwart vnd Volcher di heten ovch vernomen ### vmb dise geste si waren vro gemvt ### si enpfiengen vor dem chvnige di ritter edel vnd gvt
###### 1186 | ### Do sprach ce sinem herren von Tronege Hagene ### ez solden immer dienen dise degene ### daz vns der margrave ce liebe hat getan ### des solde lon enpfahen der schoenen Gotelinde man
###### 1187 | ### Do sprach der kvnich Gvnther ine chan daz niht verdagen ### wi sich gehaben beide daz svlt ir mir sagen ### Ecel vnd [348a] Helche vzzer Hivnen lant
| ### Do stvnt er von dem sedele mit allen sinen man ### er sprach zv dem <chvenicge> vnd mach <daz> sin getan ### daz ir mir fvrste erlovbet sone wil ich niht verdagen ### div mære div ich bringe sol ich iv vroliche sagen
###### 1189 | ### Er sprach swaz man vns mære bi iv enboten hat ### di erlovb ich iv ce sagene ane vrivnde rat ### ir svlt si lazen horen mich vnt mine man ### wand ich iv aller eren hi ce werbene gan
###### 1190 | ### Do sprach der bote biderbe iv enbivtet an den Rin ### getriwelichen dienest der groze voget min ### dar zv al den vrivnden di ir mvegt han ### ovch ist disiv botschaft mit grozen triwen getan
| ### Iv bat der kvnich edele chlagen sine not ### sin volch ist ane frevde min vrowe div ist tot ### Helche di vil riche mines herren wip ### an der nv ist verweiset vil maniger ivnchvrowen lip
###### 1192 | ### chint der edeln fvrsten div si gezogen hat ### da von iz ime lande vil <iamerliche> stat ### din hant nv leider niemen der ir mit triwen pflege ### des wen ovch sich vil seine des chveniges sorge gelege
###### 1193 | ### Nv lon im got sprach Gvnther daz er den dienest sin ### so willechlich enbivtet mir vnt den vrivnden min ### den sinen grvz ich gerne hie vernomen han ### daz svlen gerne dienen beide mage vnt mine man
| ### Do sprach von Bvrgonden der recke Gernot ### <in> mag immer riwen der schoenen Helchen tot ### dvrch ir vil manige tvgende der si chvnde pflegen ### der rede gestvnt im Hagene dar zv vil [348b] manich ander degen
###### 1195 | ### Do sprach aber Rvedger der edel bote her ### sit ir mir kvnich erlovbet ich sol iv sagen mer ### waz iv min lieber herre her enboten hat ### sit im sin dinch nach Helchen so rehte kvmmerlichen stat
###### 1196 | ### Man sagt minem herren Criemhilt si ane man ### her Sifrit si erstorben vnd ist so getan ### welt ir ir des gvennen so sol si chrone tragen ### vor Eceln recken daz hiez ir min herre sagen
| ### Do sprach der kvnich riche wol gezogen was sin mvt ### si horet minen willen ob siz gerne tvt ### den wil ich iv chvenden in disen drien tagen ### ê ichez an ir erfvnde zwiv sold ich Eceln versagen
###### 1198 | ### Di wile man den gesten hiez schaffen gvt gemach ### in wart da so gedienet daz Rvedeger des iach ### daz er da frivnde hete vnder Gvntheres man ### Hagen im diente gerne er het im ê alsam getan
###### 1199 | ### Alsvs beleip do Gvnther vnz an den dritten tach ### der kvnich nach rate sande vil wislich er pflach ### ob ez sine mage dvhte gvt getan ### daz Criemhilt nemen solde den kvenich Eceln ce man
| ### Si rieten al gemeine niwan Hagene ### der sprach ce Gvnther dem degene ### habt ir rehte sinne so wirt ez wol behut ### ob sis iv volgen wolde daz irz nimmer getvt
###### 1201 | ### War vmbe sprach do Gvnther sold ichs volgen niht ### swaz der chvneginne liebes geschiht ### des sol ich ir wol gvennen si ist div swester min ### wir soltenz selbe werben op ez ir ere mohte sin
###### 1202 | ### Do sprach aber Hagene lat di rede stan ### het ir Eceln chvende als ich sin chvende han ### sol sin danne minnen als ich ivch hore iehen ### so ist iv aller erste von schvlden sorgen geschehen
| ### Var vmb sprach do Gvnther ich behvte vil wol daz ### daz ich im chome so nahen daz ich deheinen haz ### von im dvlden mvese [349a] vnd wære sin wip ### do sprach aber Hagene ez gerætet nimmer min lip
###### 1204 | ### Man hiez nach Gernoten vnd nach Giselheren gan ### ob di herren beide dvhte gvt getan ### daz Criemhilt solde minnen den richen kvnich her ### noch widerreit ez Hagene vnd nieman mer
###### 1205 | ### Do sprach von Bvrgonden Giselher der degen ### nv mvegt ir vrivnt Hagene noh der triwen pflegen ### ergezzet si der leide vnd ir ir habt getan ### an swiv ir wol gelvnge daz soldet ir vngeveht lan
###### 1206 | ### <Ia> habt ir miner swester getan so manegiv leit ### so sprach aber Giselher der recke vil gemeit ### daz si des hete schvlde ob si iv wære gram ### nie man decheiner vrowen noch mere frevdn benam
###### 1207 | ### Daz ich daz wol bechenne daz tvn ich iv chvnt ### sol si nemen Ecel gelebt si an di stvnt ### si getvt vns noch vil leide swi siz getragt an ### ia wirt ir dienende vil manich wætlicher man
###### 1208 | ### Des antwrte Hagenn der chvne Gernot ### ez mag also beliben vnz an ir beider tot ### daz wir geriten nimmer in Eceln lant ### wir svln ir sin getriwe daz ist ce den eren vns gewant
| ### Do sprach aber Hagene mir mach niemen widersagen ### vnd sol div edele Criemhilt Helchen chrone tragen ### si getvt vns noch vil leide swi <si> gefvege daz ### ir svlt iz lan beliben daz zimt iv recken michel baz
###### 1210 | ### Mit zorn sprach do Giselher der schoenen Vten svn ### wir svln doch niht alle meinlichen tvn ### swaz eren ir <geschehe> vro solten wir des sin ### swaz ir geredet Hagene ich dien ir dvrch di triwe min
###### 1211 | ### Do daz gehorte Hagene do wart er vngemvt ### Gernot vnd Giselher di stolzen ritter gvt ### vnd Gventher der riche ce ivngest reiten daz ### ob ez lobt [349b] Criemhilt si woltenz lazzen ane haz
| ### Do sprach der fvrste Gêre ich wilz der vrowen sagen ### daz si ir den kvenech Ecel laze wol behagen ### dem ist so manich recke vnde grozen vorhten vndertan ### <Er> mach si wol ergezzen swaz ir leides ist getan
###### 1213 | ### Do gie der snelle recke da er Crimhilde ### si enpfie in gvtliche wi bald er do sprach ### ir mvegt mich gerne grvezzen vnd geben botembrot ### <ivch wil> gelvke scheiden vil schiere vz aller iwer not
###### 1214 | ### Ez hat dvrch iwer minne vrowe her gesant ### ein der aller beste der ie chveneges lant ### gewan mit vollen eren oder chrone solde tragen ### ez werbent ritter edele daz hiez iv iwer brvder sagen
| ### Do sprach div iamers riche iv sol verbieten got ### vnd allen minen vrivnden daz si deheinen spot ### an mir armer veben waz sold ich einem man ### der ie herceliebe von gvtem wibe gewan
###### 1216 | ### Si widerreit ez sere do chom aber sint ### Gernot ir brvder vnt Giselher daz chint ### da baten minnechliche trosten si ir mvt ### ob si den kvnich genæme ez wær <ir> wærlichen gvt
###### 1217 | ### Vberwinden chvnde niemen do daz wip ### daz si minnen wolde deheines mannes lip ### do baten si di degene nv lazet doch gesehen ### ob ir anders niht getvt daz ir den boten rvchet sehen
| ### Daz eine wil ich niht versprechen sprach daz vil edel wip ### ichen sehe gerne den Rvedgeres lip ### dvrch sine manige tvgende wær er her niht gesant ### swerz ander boten wære dem wær ich immer vmbechant
###### 1219 | ### Si sprach ir svlt in morgen hiezen her gan ### zv miner kemenate ich wil in hoeren lan ### vil gar den minen willen sol ich im selbe sagen ### ir wart eritteniwet [350a] daz ir vil groezlichez clagen
###### 1220 | ### Do gert ovch niht anders der edel Rvedger ### wan daz er gesæhe di <chvenegin> her ### er weste sich so wisen ob ez imer sold ergan ### daz si sich den recken veberreden mvese lan
| ### Des andern morgens vrv do man di messe sanch ### di edeln boten <chomen> do wart da groz gedranch ### di mite Rvedgere ce hove wolden gan ### so sah man da gechleidet vil manigen herlichen man
###### 1222 | ### Criemhilt div here vnd vil trvrech gemvt ### si warte Rvedger dem edeln boten gvt ### der vant si in dr wæte di si alle tage trvch ### da bi trvch ir gesinde richer chleider genvch
###### 1223 | ### Si giench im engegene zv der tvr dan ### vnd enpfie vil gvtliche den edeln man ### niwan selbe zwelfter er dar zv ir gie ### man bot im grozen dienest irn chomen hoher boten nie
| ### <Man> hiez den herren sitzen vnd sine man ### di zwene margraven di sah man vor ir stan ### Eckewart vnd Gêre di edeln recken gvt ### dvrch di hvsvrowen si sahen niemen wol gemvt
###### 1225 | ### Si sahen vor ir sizzen vil manich schoene wip ### do pflach niwan iamers der Criemhilde lip ### ir wat was vor den brvesten von heizen træhen naz ### der edel margrave sah wol an Criemhilde daz
###### 1226 | ### Do sprach der bote here vil edeles chvniges chint ### mir vnt minen gesellen di mit mir chomen sint ### svlt ir daz erlovben daz wir vor iv stan ### vnd iv sagen mære war nach wir her geritten han
| ### Nv si iv erlovbet sprach div chvenegin ### swaz ir reden wellet also stat min sin ### daz ich ez gerne hore ir sit ein bote gvt ### di andern do wol hor [350b] ten ir vnwilligen mvt
###### 1228 | ### Do sprach von Bechelaren der fvrste Rvedger ### mit triwen groze liebe Ecel ein kvnich her ### hat iv enboten vrowe her in dizze lant ### er hat nah iwer minne vil gvte recken her gesant
###### 1229 | ### Ern enbivtet iv innechlichen minne ane leit ### stæter vrivntschefte der si er iv bereit ### als er ê tet vrovn Helchen div im ce hercen lach ### ia hat er nach ir tvgenden vil diche vnvrolichen tach
| ### Do sprach div chvneginne margrave Rvdeger ### wær iemen der bechande miniv starchen ser ### der bæte mich niht trivten noch deheinen man ### ia verlos ich ein den besten den ie vrowe ie gewan
###### 1231 | ### Waz mach ergezen leides sprach der vil chvene man ### wan frivntliche liebe swer di chan began ### vnt der dan einen chivset der im ce rehte chvmt ### vor hercelicher leide niht so grozliche frvmt
###### 1232 | ### Und gervchet ir ce minnen den edeln herren min ### zwelf vil richer chrone svlt ir gewaltech sin ### dar zv git iv min herre wol drizech fvrsten lant ### div elliv hat betwngen sin vil ellenthaftiv hant
| ### Ir svlt ovch werden vrowe vber manigen werden man ### di miner vrowen Helchen waren vndertan ### vnd veber manige vrowen der si het gewalt ### von hoher fvrsten chvenne sprach der chvene degen balt
###### 1234 | ### Dar zv git iv min herre heizet er iv sagen ### ob ir gervchet chrone bi dem kvenige tragen ### gewalt den aller hohesten den Helche ie gewan ### den svlt ir gewaltechliche haben vor Ecelen man
###### 1235 | ### Do sprach div chvneginne wi mohte min lip ### immer des gelvsten deich wrde heldes wip ### mir hat der tot an einem so rehte leit getan ### des ich vnz an min ende mvz vnvroliche stan
| ### Do sprachen aber di Hivnen kvneginne rich ### iwer leben wirt bi Ecel so reht [351a] lobelich ### daz <ivch> immer wndert ist daz ez ergat ### want der kvnich riche vil manigen cieren degen hat
###### 1237 | ### Helchen ivnchvrowen vnt iwer magedin ### solten di bi ein ander ein gesinde sin ### da bi mohten recken werden wol gemvt ### lat ez iv vrowe raten ez wirt iv wærlichen gvt
###### 1238 | ### Si sprach in ir zvehten nv lat di rede stan ### vnze morgen vrv so svlt ir her gan ### ich wil iv antwrten des ir da habt mvt ### des mvsen do gevolgen di recken chven vnde gvt
| ### Do si cen herbergen alle chomen dan ### do hiez div edel vrowe nach Giselhern gan ### vnd ovch nach ir mvter den beden sagt si daz ### daz si gezæme weinen vnd niht anderes baz
###### 1240 | ### Do sprach ir brvder Giselher swester mir ist geseit ### vnd wilz ovch wol belovben daz elliv diniv leit ### der kvnich Ecel swende vnd nimestvn ceinem man ### swaz iemen ander rate so dvncht ez mich wol getan
###### 1241 | ### Er mach dich wol ergezzen sprach aber Giselher ### vome Rotten zv dem Rine von der Elbe vnz an daz mer ### so ist kvenech deheiner so gewaltech niht ### dv maht dich vrowen balde so er din ce chonen <giht>
| ### Si sprach min vil lieber brvder zwiv rætest mir daz ### chlagen vnd weinen mir immer zæme baz ### wi sold ich vor recken da ce hove gan ### wart min lip ie schone des pin ich ane getan
###### 1243 | ### Do sprach div vrowe Vote ir lieben tohter zv ### swaz dine brvder raten liebez chint daz tv ### volge dinen frivnden so mach dir wol <geshehen> ### ich han dich doh so lange mit grozem iamer gesehen
###### 1244 | ### Do bat si got vil diche fvegen ir den rat ### daz si ce geben hete got <silber> vnd wat ### sam ê bi ir manne do er noch was gesvnt ### si belebte doch nimmer mere [351b] sit so vroliche stvnt
| ### Si gedahte in ir sinnen vnd sol ich minen lip ### geben einem heiden ich pin ein christen wip ### des mvz ich cer werlde immer schaden han ### gæbe mir elliv riche ez ist von mir vil vngetan
###### 1246 | ### Da mit siz lie beliben di naht vnz an den tach ### div vrowe an ir bette mit vil gedanchen lach ### div ir vil liehtv ovgen getrvchenten nie ### vnz daz si <aber> den morgen hince mettene gie
###### 1247 | ### Ze rehter messecite di chvnige waren chomen ### si heten aber ir swester vnder hende genomen ### ia rieten si ir ze minnen den kvnich von Hivnen lant ### di vrowen ir deheiner lvecel vroliche vant
| ### Do hiez man dar gewinnen di Eceln man ### di nv mit vrlovbe wæren gerne dan ### geworben oder gescheiden swi ez do moehte sin ### ce hove chom do Rvedger di helde reiten vnder in
###### 1249 | ### daz man reht erfvere des edeln fversten mvt ### vnd tæten daz becite daz divhtes alle gvt ### ir wege wæren verre wider in ir lant ### man brahte Rvedegern da er Criemhilde vant
###### 1250 | ### Vil minnechliche piten der recke do began ### di edeln chveneginne si solde in horen lan ### waz si enbieten wolde in Eceln lant ### er wæn an ir niht anders niwan lavgenen vant
| ### Daz si nimmer minnen wolde mer deheinen man ### do sprach der margrave daz wære missetan ### zwiv woldet ir verderben einn als schoenen lip ### ir mvegt noch mit eren werden gvtes mannes wip
###### 1252 | ### Niht half daz si gebaten vnz Rvedger ### si gesprach in heimliche di chveneginne her ### er wolde si ergzen swaz ir ie gesach ### ein teil begonde ir senften do ir grozer vngemach
###### 1253 | ### Er sprach cer kvneginne lat iwer weinen sin ### ob ir ce Hivnen hetet niemen danne min ### getriwer miner mage vnd [352a] ovch <der> miner man ### er mveses ser engelten vnt het iv iemen iht getan
| ### Da von wart wol geringet do der vrowen mvt ### si sprach so swert mir eide swaz mir iemen getvt ### daz ir sit der næhste der bveze minv leit ### do sprach der margrave vrowe des pin ich bereit
###### 1255 | ### Mit allen sinen mannen swr ir do Rvedger ### mit triwen immer dienen vnt daz di recken her ### ir nimmer niht versageten vz Eceln lant ### des si ere haben solde des sichert ir Rvedegers hant
###### 1256 | ### Do gedahte div getriwe sit ich vrivnde han ### also vil gewnnen so sol ich reden lan ### di livte swaz <wellen> ich iamerhaftez wip ### waz ob noch wirt errochen des minen liebn mannes lip
###### 1257 | ### <si> gedahte sit daz Ecel der recken hat so vil ### sol ich den gebieten so tvn ich swaz ich wil ### er ist ovch wol so riche daz ich ce geben han ### mich hat der leidege Hagene mines gvtes an getan
###### 1258 | ### Si sprach ce Rvedgere het ich daz vernomen ### daz er niht wære ein heiden so wold ich gerne chomen ### swar er hete willen vnd næm in ceinem man ### do sprah der margrave di rede svlt ir vrowe lan
###### 1259 | ### Er <hat> so vil der recken in cristenlicher ê ### daz iv bi dem chvenige nimmer wirdet we ### waz ob ir daz verdienet daz er tovffet sinen lip ### des mvegt ir gerne werden des kvnich Eceln wip
| ### Do sprach aber ir brvder nv lob iz swester min ### iwer vngemvete daz svlt ir lazen sin ### si batens also lange vnz doch ir trvrech lip ### lobte vor den helden si werde Eceln wip
###### 1261 | ### Si sprach ich wil iv volgen ich armiv kvnegin ### daz ich var zv den Hivnen so daz nv mach gesin ### swenne ich han di vrivnde di mich fveren in sin lant ### des bot do vor den helden div schone [352b] Criemhilt ir hant
###### 1262 | ### Do sprach der margrave habt ir zwene man ### darzv han ich ir mere erz wirdet wol getan ### daz wir ivch wol nach eren bringen vber Rin ### ir svlt niht vrowe langer hi cen Bvergonden sin
###### 1263 | ### <Ich> han fvnhvndert manne vnd ovch der mage min ### di svln <iv> hi dienen vnt da heime sin ### vrowe swi ir gebietet ich tvn iv selbe alsam ### swenne ir mich mant der mære daz ich miches nimmer gesham
###### 1264 | ### Nv heizet iv bereiten iwer pfærtchleit ### di Rvedgeres ræte iv nimmer werden leit ### vnd sagetez iwern magedin di ir da fveren welt ### ia chvmt vns vf der straze vil manich vzerwelter helt
###### 1265 | ### Si heten noch gesmide daz man da vor reit ### bi Sifrides ziten daz si vil manige meit ### mit eren mohte fveren swenne si wolde dan ### hey waz man gvter sætele den schoenen vrowen gewan
| ### Ob si ê ie getrvgen deheiniv richen kleit ### der wart zv zir verte vil manigez nv bereit ### wand in von dem kvnige so vil gesaget wart ### si slvzen vf di chisten di ê stvnden wol bespart
###### 1267 | ### Si waren vil vnmvezech wol fvenftehalben tach ### si svchten vz der valden des vil dar inne lach ### Criemhilt do ir kamer al entslizen began ### si wolde machen riche alle Rvdegeres man
###### 1268 | ### Si hete noch des goldes von Nibelvnge lant ### si wand ez cen Hivnen <teiln> solde ir hant ### daz ez wol hvndert moere ninder chvnden tragen ### div mære horte Hagene do von Criemhilde sagen
###### 1269 | ### <Er> sprach sit mir vrov Criemhilt nimmer wirdet holt ### so mvz ovch hi belibn daz Sifrides golt ### zwiv sold ich minen finden lan so michel gvt ### ich weiz wol waz Criemhilt mit disem shaze getvt
###### 1270 | ### Ob si in brehte hinnen ich wil gelovbn daz ### er wrde doch certeilet vf den minen haz ### sin habnt ovch niht der rosse di [353a] in solden tragen ### in wil behalten Hagene daz sol man Criemhilde sagen
###### 1271 | ### Do si gehorte div mære do was ir grimme leit ### ez wart ovch den kvenegen allen drin geseit ### si woltenz gerne wenden do des niht geschach ### Rvedger der edele harte vroliche sprach
| ### B <Richiv> chvneginne zwiv chlagt ir daz golt ### iv ist der chvnich Ecel so grozlichen holt ### gesehent ivch siniv ovgen er git iv also vil ### daz irz verswendet nimmer des ich iv vrowe sweren wil
###### 1273 | ### Do sprach div chveneginne vil edel Rvedger ### ez gewan chvniges tohter nie richeite mer ### danne der mich Hagene ane hat getan ### do chom ir brvder Gernot hin zir kemenaten gegan
###### 1274 | ### Mit gewalt des chveniges den slvezel stiez er an di tver ### golt daz Criemhilde reichte man dar fver ### ce drizech tvsent marchen oder dannoch baz ### er hiez iz nemn di geste liep was Gvnthere daz
###### 1275 | ### <do> sprach von Bechelaren der Gotelinde man ### ob ez min vrowe Criemhilt allez moehte han ### swas sin ie wart gefveret von Nibelvnge lant ### sin solde lvecel rveren min oder der kveneginne hant
###### 1276 | ### Nv heizet ez behalten wand iches nine wil ### ia fvrt ich von lande des minen also vil ### daz <wirs> vf der straze haben gvten rat ### vnd vnser choste hinnen harte herlichen stat
###### 1277 | ### Da vor in aller wile gefvllet zwelf schrin ### des aller besten goldes daz inder mohte sin ### heten di ir megde daz fvrt man von dan ### vnd gezierde vil der vrowen daz si cir verte solde han
| ### D <Gewalt> des grimmen Hagenen dvhte si ce starch ### si het ir opffergoldes noch wol tvsent march ### si teiltez siner sele ir vil liebem man ### daz dvhte Rvedgern mit grozen triwen getan
###### 1279 | ### Do sprach div chlagende vrowe wa [353b] sint di vrivnde min ### di dvrch mine liebe wellent ellende sin ### di svln mit mir riten in der Hivnen lant ### di nemen shaz den minen vnd chovffen ros vnt ovch gewant
###### 1280 | ### Do sprach cer kveneginne der margrave Eckewart ### sit daz ich alerste iwer gesind wart ### so han ich iv mit triwen gedient sprach der degen ### vnd wil vnz an <minen> ende des selgen immer bi ib pflegen
###### 1281 | ### <ich> wil ovch mit mir fveren fvnfhvndert minen man ### der ich iv ce dienste mit rehten triwen gan ### wir sin vil vngescheiden ezen tv dan der tot ### der rede neig im Criemhilt des gie ir wærliche not
###### 1282 | ### Do zoch man dan di moere si wolden varn dan ### da wart vil michel weinen von vrivnden getan ### Vte div vil riche vnd manich schone meit ### di zeigeten daz in wære nach vrovn Criemhilde leit
###### 1283 | ### Hvndert richer magede fvrt si mit ir dan ### di wrden so gechleidet als in wol gezam ### do vielen in di trehene von liehten ovgen nider ### si gelebt vil der vrevden ovch bi Eceln sider
| ### Do chom der herre Giselher vnd ovch Gernot ### mit ir gesinde als in ir zvht gebot ### do wolden si beleiten ir liebe swester dan ### do fvrten si ir rechen wol tvsent wætlicher man
###### 1285 | ### Do chom der snelle Gere vnd ovch Ortwin ### Rvmolt der chvchenmeister da mite mvse sin ### si svffen di nahtselde vnz an Tvonowe stat ### do reit niht fverbaz Gvnther wan ein lvecel fvr di stat
###### 1286 | ### ê si von Rine fveren si heten fver gesant ### ir boten harte snelle in der Hivnen lant ### di dem chvnige sageten daz im Rvedger ### ce wibe het erworben di edeln kvneginne her

<<< Übersicht <<< vorige Seite nächste Seite >>>